@@ -3,34 +3,22 @@ package Text::Wrap::Smart::XS;
 use strict;
 use warnings;
 use base qw(Exporter);
-use boolean qw(true);
 
 use Carp qw(croak);
-use Params::Validate ':all';
 
 our ($VERSION, @EXPORT_OK, %EXPORT_TAGS, @subs);
 
-$VERSION = '0.06_04';
+$VERSION = '0.01';
 @subs = qw(exact_wrap fuzzy_wrap);
 @EXPORT_OK = @subs;
 %EXPORT_TAGS = ('all' => [ @subs ]);
 
 use constant WRAP_AT_DEFAULT => 160;
 
-validation_options(
-    on_fail => sub
-{
-    my ($error) = @_;
-    chomp $error;
-    croak $error;
-},
-    stack_skip => 2,
-);
-
 sub exact_wrap
 {
-    _validate(@_);
     my ($text, $wrap_at) = @_;
+    croak "exact_wrap(\\\$text [, \$wrap_at ])\n" unless defined $text;
 
     $wrap_at ||= WRAP_AT_DEFAULT;
 
@@ -39,22 +27,14 @@ sub exact_wrap
 
 sub fuzzy_wrap
 {
-    _validate(@_);
     my ($text, $wrap_at) = @_;
+    croak "fuzzy_wrap(\\\$text [, \$wrap_at ])\n" unless defined $text;
 
     $wrap_at ||= WRAP_AT_DEFAULT;
 
     return xs_fuzzy_wrap($text, $wrap_at);
 }
 
-sub _validate
-{
-    validate_pos(@_,
-        { type => SCALAR },
-        { type => SCALAR, optional => true, regex => qr/^\d+$/ },
-    );
-}
-
 require XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
 
@@ -63,7 +43,7 @@ __END__
 
 =head1 NAME
 
-Text::Wrap::Smart::XS - Wrap text fast into chunks of similar length
+Text::Wrap::Smart::XS - Wrap text fast into chunks of (mostly) equal length
 
 =head1 SYNOPSIS
 
@@ -85,23 +65,19 @@ C<Text::Wrap::Smart::XS> is the faster companion of C<Text::Wrap::Smart>.
  @chunks = exact_wrap($text [, $wrap_at ]);
 
 Wrap a text of varying length into exact chunks (except the last one,
-which consists of the remaining text).
-
-Optionally a wrapping length may be specified; if no length is supplied,
-a default of 160 will be assumed.
+which consists of the remaining text). Optionally a wrapping length
+may be specified; if no length is supplied, a default of 160 will be
+assumed.
 
 =head2 fuzzy_wrap
 
  @chunks = fuzzy_wrap($text [, $wrap_at ]);
 
 Wrap a text of varying length into chunks of fuzzy length (the boundary
-is normally calculated from the last whitespace preceding the wrapping length,
-and if no remaining whitespace could be find, the end of text; if the wrapping
-length is smaller than the size of a word, greedy wrapping will be applied: all
-characters until the first whitespace encountered form a chunk).
-
-Optionally a wrapping length may be specified; if no length is supplied,
-a default of 160 will be assumed.
+is calculated from the last whitespace preceeding the wrapping length,
+and if no remaining whitespace could be find, the end-of-text. Optionally
+a wrapping length may be specified; if no length is supplied, a
+default of 160 will be assumed.
 
 =head1 EXPORT
 
@@ -113,15 +89,6 @@ C<exact_wrap(), fuzzy_wrap()> are exportable.
 
 C<:all - *()>
 
-=head1 BUGS & CAVEATS
-
-The wrapping length will not be applied directly, but is used
-to calculate the average length to split text into chunks.
-
-Text will be normalized prior to being processed, i.e. leading
-and trailing whitespace will be chopped off before each remaining
-whitespace is converted to a literal space.
-
 =head1 SEE ALSO
 
 L<Text::Wrap>, L<Text::Wrap::Smart>
@@ -135,6 +102,6 @@ Steven Schubiger <schubiger@cpan.org>
 This program is free software; you may redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See L<http://dev.perl.org/licenses/>
+See L<http://www.perl.com/perl/misc/Artistic.html>
 
 =cut
